      pro ReadMarkIII

;       N    = The number of objects (galaxies, groups or clusters) in
;              the catalog
;       ig   = serial number
;       ic   = number in subset, according to:
;              0   - 499 - ellipticals, Lynden-Bell et al. 1988
;              500 - 599 - Aaronson et al. 1982
;              600 - 600 - Han & Mould clusters,  1990, 1992.
;              700 - 899 - Courteau & Faber 1992
;              900 - 999 - Willick 1991
;              1000 -    - Mathewson et al. 1992
;       sgl  = Supergalactic logtitude, L in degrees
;       sgb  = Supergalactic latitude,  B in degrees
;       slog = log of (linewidth in  km/s)
;       em   = apparent Tully-Fisher magnitude
;       izcmb= Redshift in CMB frame, in km/s
;       itfd = TF distance in km/s
;       delta=relative distance error
;       gnam = galaxy name  (only in the real catalog)
;       cnam = cluster name (only in the real catalog)


      baseDAT='/mybase/'
      extDAT='mark3.dat'

      fname=strcompress(baseDAT+extDAT,/remove_all)

      print,'Reading : ',fname
       
      ngals=0L
      ig=0L
      ic=0L
      ng=0L
      sgl=0.
      sgb=0.
      slog=0.
      em=0.
      izcmb=0L
      itfd=0L
      delta=0.

      gname=''
      cname=''
      
      close,1 
      openr, 1, fname

      readf,1 
      readf,1,ngals
     
      print,'Found ngals : ',ngals

      readf,1,format='(a4,a5,a4,a7,a7,a7,a6,a6,a6,a6,1x,a10,1x,a10)' 
      
      for iloop=0,ngals-1 do begin

         readf,1, ig,ic,ng,sgl,sgb,slog,em,izcmb,itfd,delta,gname,cname,$
           format='(i4,i5,i4,f7.2,f7.2,f7.3,f6.2,i6,i6,f6.3,1x,a10,1x,a10)'

;         print,'ig,ic,ng,sgl,sgb,izcmb,itfd,delta,gname,cname : ',$
;           ig,ic,ng,sgl,sgb,izcmb,itfd,delta,gname,cname

      endfor
         
      close,1
         
      print,'Reading completed ...'

      stop
      end


